@@ -152,61 +152,67 @@ extern int yydebug;
     COCO_ELSE = 353,               /* COCO_ELSE  */
     COCO_ELIF = 354,               /* COCO_ELIF  */
     COCO = 355,                    /* COCO  */
-    INCLUDE = 356,                 /* INCLUDE  */
-    INCLUDE_CPP = 357,             /* INCLUDE_CPP  */
-    INCLUDE_CPP_STD = 358,         /* INCLUDE_CPP_STD  */
-    INCLUDE_COCO = 359,            /* INCLUDE_COCO  */
-    INCFILENAME = 360,             /* INCFILENAME  */
-    USE = 361,                     /* USE  */
-    SEGMENT = 362,                 /* SEGMENT  */
-    ENDSEGMENT = 363,              /* ENDSEGMENT  */
-    ESOPE = 364,                   /* ESOPE  */
-    IDENTIFIER = 365,              /* IDENTIFIER  */
-    CIDENTIFIER = 366,             /* CIDENTIFIER  */
-    SKIP = 367,                    /* SKIP  */
-    SKIPALL = 368,                 /* SKIPALL  */
-    SKIPNOOP = 369,                /* SKIPNOOP  */
-    SKIPNOS = 370,                 /* SKIPNOS  */
-    KEYWORD = 371,                 /* KEYWORD  */
-    ELEMENTAL = 372,               /* ELEMENTAL  */
-    IMPURE = 373,                  /* IMPURE  */
-    PURE = 374,                    /* PURE  */
-    SIMPLE = 375,                  /* SIMPLE  */
-    RECURSIVE = 376,               /* RECURSIVE  */
-    NON_RECURSIVE = 377,           /* NON_RECURSIVE  */
-    SUBROUTINE = 378,              /* SUBROUTINE  */
-    FUNCTION = 379,                /* FUNCTION  */
-    PROGRAM = 380,                 /* PROGRAM  */
-    EOL = 381,                     /* EOL  */
-    NAMED_LABEL = 382,             /* NAMED_LABEL  */
-    STLABEL = 383,                 /* STLABEL  */
-    LABEL = 384,                   /* LABEL  */
-    LABELS = 385,                  /* LABELS  */
-    LABELLIST = 386,               /* LABELLIST  */
-    CALL = 387,                    /* CALL  */
-    STARTCALL = 388,               /* STARTCALL  */
-    CALLLIST = 389,                /* CALLLIST  */
-    TYPE = 390,                    /* TYPE  */
-    ENDTYPE = 391,                 /* ENDTYPE  */
-    CLASS = 392,                   /* CLASS  */
-    BASICTYPE = 393,               /* BASICTYPE  */
-    TYPEC = 394,                   /* TYPEC  */
-    QSTRING = 395,                 /* QSTRING  */
-    HSTRING = 396,                 /* HSTRING  */
-    LR = 397,                      /* LR  */
-    LRB = 398,                     /* LRB  */
-    DOTOPERATOR = 399,             /* DOTOPERATOR  */
-    I_NUMBER = 400,                /* I_NUMBER  */
-    UNCLASSIFIED = 401,            /* UNCLASSIFIED  */
-    ERROR = 402,                   /* ERROR  */
-    OMP = 403,                     /* OMP  */
-    SCANOMPFIXED = 404,            /* SCANOMPFIXED  */
-    SCANOMPFREE = 405,             /* SCANOMPFREE  */
-    DEF = 406,                     /* DEF  */
-    EXEC = 407,                    /* EXEC  */
-    ENDDEF = 408,                  /* ENDDEF  */
-    NONE = 409,                    /* NONE  */
-    LAST_TOKEN = 410               /* LAST_TOKEN  */
+    FYPP_IF = 356,                 /* FYPP_IF  */
+    FYPP_ENDIF = 357,              /* FYPP_ENDIF  */
+    FYPP_ELSE = 358,               /* FYPP_ELSE  */
+    FYPP_ELIF = 359,               /* FYPP_ELIF  */
+    FYPP = 360,                    /* FYPP  */
+    INCLUDE = 361,                 /* INCLUDE  */
+    INCLUDE_CPP = 362,             /* INCLUDE_CPP  */
+    INCLUDE_CPP_STD = 363,         /* INCLUDE_CPP_STD  */
+    INCLUDE_COCO = 364,            /* INCLUDE_COCO  */
+    INCLUDE_FYPP = 365,            /* INCLUDE_FYPP  */
+    INCFILENAME = 366,             /* INCFILENAME  */
+    USE = 367,                     /* USE  */
+    SEGMENT = 368,                 /* SEGMENT  */
+    ENDSEGMENT = 369,              /* ENDSEGMENT  */
+    ESOPE = 370,                   /* ESOPE  */
+    IDENTIFIER = 371,              /* IDENTIFIER  */
+    CIDENTIFIER = 372,             /* CIDENTIFIER  */
+    SKIP = 373,                    /* SKIP  */
+    SKIPALL = 374,                 /* SKIPALL  */
+    SKIPNOOP = 375,                /* SKIPNOOP  */
+    SKIPNOS = 376,                 /* SKIPNOS  */
+    KEYWORD = 377,                 /* KEYWORD  */
+    ELEMENTAL = 378,               /* ELEMENTAL  */
+    IMPURE = 379,                  /* IMPURE  */
+    PURE = 380,                    /* PURE  */
+    SIMPLE = 381,                  /* SIMPLE  */
+    RECURSIVE = 382,               /* RECURSIVE  */
+    NON_RECURSIVE = 383,           /* NON_RECURSIVE  */
+    SUBROUTINE = 384,              /* SUBROUTINE  */
+    FUNCTION = 385,                /* FUNCTION  */
+    PROGRAM = 386,                 /* PROGRAM  */
+    EOL = 387,                     /* EOL  */
+    NAMED_LABEL = 388,             /* NAMED_LABEL  */
+    STLABEL = 389,                 /* STLABEL  */
+    LABEL = 390,                   /* LABEL  */
+    LABELS = 391,                  /* LABELS  */
+    LABELLIST = 392,               /* LABELLIST  */
+    CALL = 393,                    /* CALL  */
+    STARTCALL = 394,               /* STARTCALL  */
+    CALLLIST = 395,                /* CALLLIST  */
+    TYPE = 396,                    /* TYPE  */
+    ENDTYPE = 397,                 /* ENDTYPE  */
+    CLASS = 398,                   /* CLASS  */
+    BASICTYPE = 399,               /* BASICTYPE  */
+    TYPEC = 400,                   /* TYPEC  */
+    QSTRING = 401,                 /* QSTRING  */
+    HSTRING = 402,                 /* HSTRING  */
+    LR = 403,                      /* LR  */
+    LRB = 404,                     /* LRB  */
+    DOTOPERATOR = 405,             /* DOTOPERATOR  */
+    I_NUMBER = 406,                /* I_NUMBER  */
+    UNCLASSIFIED = 407,            /* UNCLASSIFIED  */
+    ERROR = 408,                   /* ERROR  */
+    OMP = 409,                     /* OMP  */
+    SCANOMPFIXED = 410,            /* SCANOMPFIXED  */
+    SCANOMPFREE = 411,             /* SCANOMPFREE  */
+    DEF = 412,                     /* DEF  */
+    EXEC = 413,                    /* EXEC  */
+    ENDDEF = 414,                  /* ENDDEF  */
+    NONE = 415,                    /* NONE  */
+    LAST_TOKEN = 416               /* LAST_TOKEN  */
   };
   typedef enum yytokentype yytoken_kind_t;
 #endif
