@@ -1,5 +1,5 @@
 /* -copyright-
-#-# Copyright: 2015-2024 Willem Vermin wvermin@gmail.com
+#-# Copyright: 2015-2025 Willem Vermin wvermin@gmail.com
 #-# 
 #-# License: BSD-3-Clause
 #-#  Redistribution and use in source and binary forms, with or without
@@ -436,6 +436,10 @@ void Docs::usage(bool man)
    manout(" ","");
    manout(" ","Refactor 'end': findent -Rr < in.f90 > out.f90");
    manout(" "," ");
+   manout(" ","NOTE: In PowerShell use something like:");
+   manout(" ","");
+   manout(" ","cat in.f | findent -i2 -r0 > out.f");
+   manout(" "," ");
    if(doman)
    {
       std::cout << ".PP" << std::endl << ".SS" << std::endl;
