@@ -1,5 +1,5 @@
 /* -copyright-
-#-# Copyright: 2015-2024 Willem Vermin wvermin@gmail.com
+#-# Copyright: 2015-2025 Willem Vermin wvermin@gmail.com
 #-# 
 #-# License: BSD-3-Clause
 #-#  Redistribution and use in source and binary forms, with or without
@@ -388,7 +388,7 @@ void Fortran::get_full_statement()
 	       break;
 	    }
 	    pregentype = Curline.getpregentype();
-	    if(pregentype == CPP || pregentype == COCO)
+	    if(pregentype == CPP || pregentype == COCO || pregentype == FYPP)
 	    {
 	       state = in_pre;
 	       break;
@@ -398,7 +398,7 @@ void Fortran::get_full_statement()
 	    {
 	       switch(pregentype)
 	       {
-		  case INCLUDE_CPP: case INCLUDE_CPP_STD: case INCLUDE_COCO:
+		  case INCLUDE_CPP: case INCLUDE_CPP_STD: case INCLUDE_COCO: case INCLUDE_FYPP:
 		     Includes.insert(std::make_pair(pregentype,Curline.getinclude()));
 	       }
 	    }
@@ -426,7 +426,7 @@ void Fortran::get_full_statement()
 	    // issue14
 	    // Always check if we are dealing with a preprocessor line: 
 	    pregentype = Curline.getpregentype();
-	    if(pregentype == CPP || pregentype == COCO)
+	    if(pregentype == CPP || pregentype == COCO || pregentype == FYPP)
 	    {
 	       state = in_pre;
 	       break;
@@ -443,8 +443,8 @@ void Fortran::get_full_statement()
 	       Curline = Getnext(End_of_file); 
 	       if (End_of_file) { state = end_fortran; break; }
 	       pregentype = Curline.getpregentype();
-	       D(O("issue14");O(Curline.str());O(pregentype==CPP);O(pregentype==COCO););
-	       if (pregentype == CPP || pregentype == COCO)
+	       D(O("issue14");O(Curline.str());O(pregentype==CPP);O(pregentype==COCO);O(pregentype==FYPP););
+	       if (pregentype == CPP || pregentype == COCO || pregentype == FYPP)
 	       {
 		  p_more = 0;
 		  while (1)
@@ -466,7 +466,7 @@ void Fortran::get_full_statement()
 	       {
 		  switch(pregentype)
 		  {
-		     case INCLUDE_CPP: case INCLUDE_CPP_STD: case INCLUDE_COCO:
+		     case INCLUDE_CPP: case INCLUDE_CPP_STD: case INCLUDE_COCO: case INCLUDE_FYPP:
 			Includes.insert(std::make_pair(pregentype,Curline.getinclude()));
 		  }
 	       }
@@ -535,13 +535,14 @@ void Fortran::handle_pre(Fortranline &line, bool &p_more)
 {
    int ifelse;
 
-   if((!p_more) && ( pregentype == CPP || pregentype == COCO))
+   if((!p_more) && ( pregentype == CPP || pregentype == COCO || pregentype == FYPP))
    {
       int pretype    = line.scanfixpre();
       switch(pretype)
       {
 	 case CPP:
 	 case COCO:
+	 case FYPP:
 	 case FINDENTFIX:
 	    break;
 	 default:
@@ -661,7 +662,7 @@ void Fortran::handle_pre(Fortranline &line, bool &p_more)
    }
    if(pregentype == CPP)
       p_more = (line.lastchar() == '\\');
-   else if(pregentype == COCO)
+   else if(pregentype == COCO || pregentype == FYPP)
       p_more = (line.lastchar() == '&');
    else
       p_more = 0;
@@ -728,6 +729,7 @@ void Fortran::indent_and_output()
 	    case INCLUDE_CPP:
 	    case INCLUDE_CPP_STD:
 	    case INCLUDE_COCO:
+	    case INCLUDE_FYPP:
 	       D(O("INCLUDE");O(props.stringvalue);O(FLAGS.deps););
 	       Includes.insert(std::make_pair(props.kind,trim(props.stringvalue)));
 	       break;
