@@ -1,5 +1,5 @@
 /* -copyright-
-#-# Copyright: 2015-2024 Willem Vermin wvermin@gmail.com
+#-# Copyright: 2015-2025 Willem Vermin wvermin@gmail.com
 #-# 
 #-# License: BSD-3-Clause
 #-#  Redistribution and use in source and binary forms, with or without
@@ -71,7 +71,7 @@ class Line_prep
 
       char get_place_holder(void)               { return place_holder; }
       
-      std::string get_line(void)                { return line; }
+      std::string get_line(void) const                { return line; }
 
       std::string get_line_spaces_removed(void) { return sl; }
 
